<?php
/**
 * PDF Invoicing for WooCommerce - Admin Class
 *
 * @version 1.0.0
 * @since   1.0.0
 * @author  Algoritmika Ltd
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_PDF_Invoicing_Admin' ) ) :

class Alg_WC_PDF_Invoicing_Admin {

	/**
	 * Constructor.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function __construct() {
		// Action links
		add_filter( 'plugin_action_links_' . plugin_basename( alg_wc_pdf_invoicing()->plugin_file() ), array( $this, 'action_links' ) );
		// Settings
		add_filter( 'woocommerce_get_settings_pages', array( $this, 'add_woocommerce_settings_tab' ) );
		// Version update
		if ( get_option( 'alg_wc_pdf_invoicing_version', '' ) !== alg_wc_pdf_invoicing()->version ) {
			add_action( 'admin_init', array( $this, 'version_updated' ) );
		}
		// Core
		if ( 'yes' === get_option( 'alg_wc_pdf_invoicing_plugin_enabled', 'yes' ) ) {
			add_filter( 'manage_edit-shop_order_columns',        array( $this, 'add_order_columns' ),    PHP_INT_MAX );
			add_action( 'manage_shop_order_posts_custom_column', array( $this, 'render_order_columns' ), PHP_INT_MAX );
		}
	}

	/**
	 * add_order_columns.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function add_order_columns( $columns ) {
		foreach ( apply_filters( 'alg_wc_pdf_invoicing_enabled_docs', array( '0' ) ) as $doc_id ) {
			$title = alg_wc_pdf_invoicing()->core->get_doc_option( $doc_id, 'admin_title' );
			$columns[ 'alg_wc_pdf_invoicing_doc_' . $doc_id ] = $title;
		}
		return $columns;
	}

	/**
	 * render_order_columns.
	 *
	 * @param   string $column
	 * @version 1.0.0
	 * @since   1.0.0
	 * @todo    [dev] (maybe) customizable image(s)
	 */
	function render_order_columns( $column ) {
		foreach ( apply_filters( 'alg_wc_pdf_invoicing_enabled_docs', array( '0' ) ) as $doc_id ) {
			if ( 'alg_wc_pdf_invoicing_doc_' . $doc_id === $column ) {
				$order_id = get_the_ID();
				$order    = wc_get_order( $order_id );
				if ( ! $order->has_status( 'cancelled' ) ) {
					$doc = new Alg_WC_PDF_Invoicing_Doc( $order_id, $doc_id );
					if ( $doc->is_created() ) {
						echo '<a href="' . add_query_arg( array( 'alg-wc-pdf-invoicing-view-doc' => $doc_id, 'alg-wc-pdf-invoicing-order-id' => $order_id ) ) .
							'" target="_blank">' . $doc->get_number() . '</a>' . ' ' .
						'<a href="' . add_query_arg( array( 'alg-wc-pdf-invoicing-view-doc' => $doc_id, 'alg-wc-pdf-invoicing-order-id' => $order_id,
							'alg-wc-pdf-invoicing-pdf-dest' => 'D' ) ) . '">' .
								'<img title="' . __( 'Download', 'pdf-invoicing-for-woocommerce' ) . '" src="' .
									alg_wc_pdf_invoicing()->plugin_url() . '/assets/images/download.png' . '">' . '</a>' . ' ' .
						'<a href="' . add_query_arg( array( 'alg-wc-pdf-invoicing-delete-doc' => $doc_id, 'alg-wc-pdf-invoicing-order-id' => $order_id ) ) .
							'" onclick="return confirm(\'' . __( 'Are you sure?', 'pdf-invoicing-for-woocommerce' ) . '\')">' .
								'<img title="' . __( 'Delete', 'pdf-invoicing-for-woocommerce' ) . '" src="' .
									alg_wc_pdf_invoicing()->plugin_url() . '/assets/images/delete.png' . '">' . '</a>';
					} else {
						$doc_hooks = alg_wc_pdf_invoicing()->core->get_doc_option( $doc_id, 'hooks' );
						if ( in_array( 'manual', $doc_hooks ) || empty( $doc_hooks ) ) {
							echo '<a href="' . add_query_arg( array( 'alg-wc-pdf-invoicing-create-doc' => $doc_id, 'alg-wc-pdf-invoicing-order-id' => $order_id ) ) .
								'" style="color:green;" onclick="return confirm(\'' . __( 'Are you sure?', 'pdf-invoicing-for-woocommerce' ) . '\')">' .
									__( 'Create', 'pdf-invoicing-for-woocommerce' ) . '</a>';
						}
					}
				}
			}
		}
	}

	/**
	 * action_links.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @param   mixed $links
	 * @return  array
	 * @todo    [dev] (maybe) "Go Pro!"
	 */
	function action_links( $links ) {
		$custom_links = array();
		$custom_links[] = '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=alg_wc_pdf_invoicing' ) . '">' . __( 'Settings', 'woocommerce' ) . '</a>';
		if ( 'pdf-invoicing-for-woocommerce.php' === basename( alg_wc_pdf_invoicing()->plugin_file() ) ) {
			$custom_links[] = '<a target="_blank" href="https://wpfactory.com/item/pdf-invoicing-for-woocommerce/">' .
				__( 'Unlock All', 'pdf-invoicing-for-woocommerce' ) . '</a>';
		}
		return array_merge( $custom_links, $links );
	}

	/**
	 * add_woocommerce_settings_tab.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function add_woocommerce_settings_tab( $settings ) {
		$settings[] = require_once( 'settings/class-alg-wc-pdf-invoicing-settings.php' );
		return $settings;
	}

	/**
	 * version_updated.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function version_updated() {
		update_option( 'alg_wc_pdf_invoicing_version', alg_wc_pdf_invoicing()->version );
	}

}

endif;

return new Alg_WC_PDF_Invoicing_Admin();
