<?php
/**
 * PDF Invoicing for WooCommerce - Shortcodes Class
 *
 * @version 1.1.0
 * @since   1.0.0
 * @author  Algoritmika Ltd
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_PDF_Invoicing_Shortcodes' ) ) :

class Alg_WC_PDF_Invoicing_Shortcodes {

	/**
	 * Constructor.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @todo    [dev] optional/customizable shortcodes prefix
	 */
	function __construct() {
		$this->props = array();
		add_shortcode( 'prop',      array( $this, 'shortcode_prop' ) );
		add_shortcode( 'each_item', array( $this, 'shortcode_each_item' ) );
		add_shortcode( 'if',        array( $this, 'shortcode_if' ) );
		add_shortcode( 'clear',     array( $this, 'shortcode_clear' ) );
	}

	/**
	 * set_doc_obj.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function set_doc_obj( $obj ) {
		$this->doc_obj = $obj;
	}

	/**
	 * set_prop.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function set_prop( $prop, $value ) {
		$this->props[ $prop ] = $value;
	}

	/**
	 * shortcode_clear.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function shortcode_clear( $atts, $content = '' ) {
		return '<p></p>';
	}

	/**
	 * shortcode_if.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function shortcode_if( $atts, $content = '' ) {
		if ( ! isset( $atts['value1'], $atts['operator'], $atts['value2'] ) || '' === $content ) {
			return '';
		}
		$value1 = do_shortcode( str_replace( array( '{', '}' ), array( '[', ']' ), $atts['value1'] ) );
		$value2 = do_shortcode( str_replace( array( '{', '}' ), array( '[', ']' ), $atts['value2'] ) );
		switch ( $atts['operator'] ) {
			case 'equal':
				return ( $value1 == $value2 ? do_shortcode( $content ) : '' );
			case 'not_equal':
				return ( $value1 != $value2 ? do_shortcode( $content ) : '' );
			case 'less':
				return ( $value1 <  $value2 ? do_shortcode( $content ) : '' );
			case 'less_or_equal':
				return ( $value1 <= $value2 ? do_shortcode( $content ) : '' );
			case 'greater':
				return ( $value1 >  $value2 ? do_shortcode( $content ) : '' );
			case 'greater_or_equal':
				return ( $value1 >= $value2 ? do_shortcode( $content ) : '' );
		}
		return '';
	}

	/**
	 * shortcode_each_item.
	 *
	 * @version 1.0.1
	 * @since   1.0.0
	 * @todo    [dev] (maybe) rethink naming, e.g. `[each name="items"]`
	 */
	function shortcode_each_item( $atts, $content = '' ) {
		if ( '' === $content ) {
			return '';
		}
		$order  = wc_get_order( $this->doc_obj->order_id );
		$output = '';
		$this->order_item_nr = 0;
		$this->order_item    = false;
		$this->item_product  = false;
		foreach ( $order->get_items() as $item_id => $item ) {
			$this->order_item_nr++;
			$this->order_item   = $item;
			$this->item_product = $item->get_product();
			$output .= do_shortcode( $content );
		}
		unset( $this->order_item_nr );
		unset( $this->order_item );
		unset( $this->item_product );
		return $output;
	}

	/**
	 * return_prop.
	 *
	 * @version 1.0.2
	 * @since   1.0.0
	 * @todo    [dev] (maybe) `on_empty`; `lang` && `not_lang`; `order_billing_country` && `not_order_billing_country` etc. OR maybe all that can be done via `[if]`?
	 */
	function return_prop( $value, $atts ) {
		if ( is_numeric( $value ) ) {
			if ( ! empty( $atts['add'] ) ) {
				$value += $atts['add'];
			}
			if ( ! empty( $atts['multiply'] ) ) {
				$value *= $atts['multiply'];
			}
		}
		if ( isset( $atts['format'] ) ) {
			switch ( $atts['format'] ) {
				case 'price':
					$value = wc_price( $value );
					break;
				default:
					$value = sprintf( $atts['format'], $value );
			}
		}
		return ( '' !== $value ? ( ( isset( $atts['before'] ) ? $atts['before'] : '' ) . $value . ( isset( $atts['after'] ) ? $atts['after'] : '' ) ) : '' );
	}

	/**
	 * is_prop_type.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function is_prop_type( $type, $prop_name ) {
		$type   = $type . '_';
		$length = strlen( $type );
		return ( $type === substr( $prop_name, 0, $length ) );
	}

	/**
	 * shortcode_prop.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 * @todo    [dev] data from another doc (e.g. display invoice nr in packing slip)
	 * @todo    [dev] `ucfirst()` for `order_total_in_words` (including Unicode)
	 * @todo    [dev] (maybe) separate shortcodes (e.g. `[doc]`, `[order]`, `[item]` etc.)
	 */
	function shortcode_prop( $atts, $content = '' ) {
		if ( ! isset( $atts['name'] ) || ( isset( $this->props[ $atts['name'] ] ) && false === $this->props[ $atts['name'] ] ) || ! isset( $this->doc_obj ) ) {
			return '';
		}

		// Prepare & check data
		if ( $this->is_prop_type( 'order', $atts['name'] ) && ! isset( $this->order ) ) {
			if ( ! isset( $this->doc_obj->order_id ) || ! ( $order = wc_get_order( $this->doc_obj->order_id ) ) ) {
				return '';
			} else {
				$this->order = $order;
			}
		} elseif ( $this->is_prop_type( 'item_product', $atts['name'] ) ) {
			if ( ! isset( $this->item_product ) ) {
				return '';
			}
		} elseif ( $this->is_prop_type( 'item', $atts['name'] ) ) {
			if ( ! isset( $this->order_item ) || ! isset( $this->order_item_nr ) ) {
				return '';
			}
		}

		// Main switch
		switch ( $atts['name'] ) {

			// Document
			case 'doc_counter':
				return $this->return_prop( $this->doc_obj->get_counter(), $atts );
			case 'doc_nr':
				return $this->return_prop( $this->doc_obj->get_number(), $atts );
			case 'doc_formatted_date':
				return $this->return_prop( $this->doc_obj->get_formatted_date(), $atts );
			case 'doc_author_full_name':
				return $this->return_prop( $this->doc_obj->get_author_full_name(), $atts );

			// Order
			case 'order_number':
				return $this->return_prop( $this->order->get_order_number(), $atts );
			case 'order_formatted_date_created':
				return $this->return_prop( date_i18n( 'Y-m-d', strtotime( $this->order->get_date_created() ) ), $atts );
			case 'order_subtotal':
				return $this->return_prop( $this->order->get_subtotal(), $atts );
			case 'order_total':
				return $this->return_prop( $this->order->get_total(), $atts );
			case 'order_total_in_words':
				$whole_part   = alg_wc_pdf_invoicing_number_to_words( intval( $this->order->get_total() ), ( isset( $atts['lang'] ) ? strtoupper( $atts['lang'] ) : 'EN' ) );
				$decimal_part = round( ( $this->order->get_total() - intval( $this->order->get_total() ) ) * 100, 2 );
				return $this->return_prop( $whole_part . ' ' . get_woocommerce_currency_symbol( $this->order->get_currency() ) . ' ' . $decimal_part . ' ' . '&cent;', $atts );
			case 'order_total_tax':
				return $this->return_prop( $this->order->get_total_tax(), $atts );
			case 'order_total_excl_tax':
				return $this->return_prop( $this->order->get_total() - $this->order->get_total_tax(), $atts );
			case 'order_shipping_total':
				return $this->return_prop( $this->order->get_shipping_total(), $atts );
			case 'order_shipping_method':
				return $this->return_prop( $this->order->get_shipping_method(), $atts );
			case 'order_payment_method_title':
				return $this->return_prop( $this->order->get_payment_method_title(), $atts );
			case 'order_formatted_billing_address':
				return $this->return_prop( $this->order->get_formatted_billing_address(), $atts );
			case 'order_formatted_shipping_address':
				return $this->return_prop( $this->order->get_formatted_shipping_address(), $atts );
			case 'order_billing_first_name':
				return $this->return_prop( $this->order->get_billing_first_name(), $atts );
			case 'order_total_items_count':
				return $this->return_prop( count( $this->order->get_items() ), $atts );
			case 'order_meta':
				return ( isset( $atts['key'] ) ? $this->return_prop( get_post_meta( $this->order->get_id(), $atts['key'], true ), $atts ) : '' );
			case 'order_details_email':
				ob_start();
				wc_get_template(
					'emails/email-order-details.php',
					array(
						'order'         => $this->order,
						'sent_to_admin' => false,
						'plain_text'    => false,
						'email'         => '',
					)
				);
				return $this->return_prop( ob_get_clean(), $atts );
			case 'order_details_table':
				ob_start();
				woocommerce_order_details_table( $this->doc_obj->order_id );
				return $this->return_prop( ob_get_clean(), $atts );
			case 'order_func':
				if ( ! isset( $atts['func'] ) ) {
					return '';
				}
				$func = $atts['func'];
				return ( is_callable( $this->order, $func ) ? $this->return_prop( $this->order->{$func}(), $atts ) : '' );

			// Order item
			case 'item_nr':
				return $this->return_prop( $this->order_item_nr, $atts );
			case 'item_name':
				return $this->return_prop( $this->order_item->get_name(), $atts );
			case 'item_qty':
				return $this->return_prop( $this->order_item->get_quantity(), $atts );
			case 'item_total':
				return $this->return_prop( $this->order_item->get_total(), $atts );
			case 'item_total_tax':
				return $this->return_prop( $this->order_item->get_total_tax(), $atts );
			case 'item_total_incl_tax':
				return $this->return_prop( $this->order_item->get_total() + $this->order_item->get_total_tax(), $atts );
			case 'item_total_tax_percent':
				return $this->return_prop( ( 0 != $this->order_item->get_total() ?
					round( $this->order_item->get_total_tax() / $this->order_item->get_total() * 100 ) : 0 ), $atts );
			case 'item_single':
				$qty = $this->order_item->get_quantity();
				return ( 0 != $qty ? $this->return_prop( $this->order_item->get_total() / $qty, $atts ) : 0 );
			case 'item_meta':
				return ( isset( $atts['key'] ) ? $this->return_prop( $this->order_item->get_meta( $atts['key'], true ), $atts ) : '' );
			case 'item_func':
				if ( ! isset( $atts['func'] ) ) {
					return '';
				}
				$func = $atts['func'];
				return ( is_callable( $this->order_item, $func ) ? $this->return_prop( $this->order_item->{$func}(), $atts ) : '' );

			// Order item product
			case 'item_product_id':
				return $this->return_prop( $this->item_product->get_id(), $atts );
			case 'item_product_sku':
				return $this->return_prop( $this->item_product->get_sku(), $atts );
			case 'item_product_taxonomy':
				if ( ! isset( $atts['taxonomy'] ) ) {
					return '';
				}
				$terms = get_the_terms( $this->item_product->get_id(), $atts['taxonomy'] );
				if ( ! $terms || is_wp_error( $terms ) ) {
					return '';
				}
				$terms = implode( ', ', wp_list_pluck( $terms, 'name' ) );
				return $this->return_prop( $terms, $atts );
			case 'item_product_meta':
				return ( isset( $atts['key'] ) ? $this->return_prop( get_post_meta( $this->item_product->get_id(), $atts['key'], true ), $atts ) : '' );
			case 'item_product_func':
				if ( ! isset( $atts['func'] ) ) {
					return '';
				}
				$func = $atts['func'];
				return ( is_callable( $this->item_product, $func ) ? $this->return_prop( $this->item_product->{$func}(), $atts ) : '' );

		}
	}

}

endif;

return new Alg_WC_PDF_Invoicing_Shortcodes();
