<?php
/**
 * PDF Invoicing for WooCommerce - Functions - Default Values
 *
 * @version 1.1.0
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! function_exists( 'alg_wc_pdf_invoicing_get_default' ) ) {
	/**
	 * alg_wc_pdf_invoicing_get_default.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 * @todo    [dev] (maybe) better defaults, e.g. HTML style & content
	 */
	function alg_wc_pdf_invoicing_get_default( $option_id, $doc_id = 0 ) {
		switch ( $option_id ) {
			case 'enable':
				return 'yes';
			case 'admin_title':
				return apply_filters( 'alg_wc_pdf_invoicing_default_doc_title', __( 'Invoice', 'pdf-invoicing-for-woocommerce' ), $doc_id );
			case 'hooks':
				return array( 'manual' );
			case 'emails':
				return array();
			case 'number_format':
				return 'INV-[prop name="doc_counter" format="%06d"]';
			case 'page_orientation':
				return 'P';
			case 'page_format':
				return 'A4';
			case 'enable_header':
				return 'yes';
			case 'header_img':
				return '';
			case 'header_title':
				return __( 'Invoice', 'pdf-invoicing-for-woocommerce' ) . ' [prop name="doc_nr"]';
			case 'header_text':
				return str_replace( "\t", '',
					'Company name
					Company address' );
			case 'enable_footer':
				return 'yes';
			case 'footer_text':
				return '%page_num% / %total_pages%';
			case 'footer_text_align':
				return 'R';
			case 'header_font_size':
				return 7;
			case 'footer_font_size':
				return 7;
			case 'font_size':
				return 8;
			case 'html_style':
				return str_replace( "\t", '',
					'table {
					    width: 100%;
					}

					table th {
					    font-weight: bold;
					}

					table, tr, th, td {
					    border: 1px solid gray;
					    border-collapse: collapse;
					    padding: 2px;
					}

					table.order-items th.price, table.order-items td.price {
					    text-align: right;
					}

					table.order-items th.qty, table.order-items td.qty {
					    text-align: center;
					}

					table.totals {
					    border: none;
					}

					table.totals th {
					    width: 90%;
					    text-align: right;
					    border: none;
					    font-weight: normal;
					}

					table.totals td {
					    width: 10%;
					    text-align: right;
					    border: none;
					    font-weight: bold;
					}
					' );
			case 'html_content':
				return str_replace( "\t", '',
					'<h1>Invoice</h1>

					<table>
					    <tbody>
					        <tr><td>Invoice nr.</td><td><strong>[prop name="doc_nr"]</strong></td></tr>
					        <tr><td>Invoice date</td><td><strong>[prop name="doc_formatted_date"]</strong></td></tr>
					        <tr><td>Order nr.</td><td>[prop name="order_number"]</td></tr>
					        <tr><td>Order date</td><td>[prop name="order_formatted_date_created"]</td></tr>
					    </tbody>
					</table>

					[clear]

					<table>
					    <tbody>
					        <tr><th>Seller</th><th>Buyer</th></tr>
					        <tr><td>Company name<br>Company address</td><td>[prop name="order_formatted_billing_address"]</td></tr>
					    </tbody>
					</table>

					[clear]

					<table class="order-items">
					    <tbody>
					        <tr><th style="width:5%">Nr.</th><th style="width:56%">Description</th><th style="width:12%">SKU</th><th class="qty" style="width:7%">Qty</th><th class="price" style="width:10%">Price (excl. tax)</th><th class="price" style="width:10%">Total (excl. tax)</th></tr>
					        [each_item]<tr><td>[prop name="item_nr"]</td><td>[prop name="item_name"]</td><td>[prop name="item_product_sku"]</td><td class="qty">[prop name="item_qty"]</td><td class="price">[prop name="item_single" format="price"]</td><td class="price">[prop name="item_total" format="price"]</td></tr>[/each_item]
					        [if value1="{prop name=\'order_shipping_total\'}" operator="greater" value2="0"]<tr><td>[prop name="order_total_items_count" add="1"]</td><td>[prop name="order_shipping_method"]</td><td></td><td class="qty">1</td><td class="price">[prop name="order_shipping_total" format="price"]</td><td class="price">[prop name="order_shipping_total" format="price"]</td></tr>[/if]
					    </tbody>
					</table>
					<table class="totals">
					    <tbody>
					        <tr><th>Total (excl. tax)</th><td>[prop name="order_total_excl_tax" format="price"]</td></tr>
					        <tr><th>Tax</th><td>[prop name="order_total_tax" format="price"]</td></tr>
					        <tr><th>Total (incl. tax)</th><td>[prop name="order_total" format="price"]</td></tr>
					    </tbody>
					</table>

					<p><strong>Total in words:</strong> [prop name="order_total_in_words"]</p>
					<p><strong>Payment method:</strong> [prop name="order_payment_method_title"]</p>

					[clear]

					<table style="margin-top: 30px">
					    <tbody>
					        <tr><th>Invoice created by:</th><td>[prop name="doc_author_full_name"]</td></tr>
					        <tr><th>Invoice accepted by:</th><td></td></tr>
					    </tbody>
					</table>
					' );
		}
	}
}
