<?php
/**
 * PDF Invoicing for WooCommerce - General Section Settings
 *
 * @version 1.0.0
 * @since   1.0.0
 * @author  Algoritmika Ltd
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_PDF_Invoicing_Settings_General' ) ) :

class Alg_WC_PDF_Invoicing_Settings_General extends Alg_WC_PDF_Invoicing_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function __construct() {
		$this->id   = '';
		$this->desc = __( 'General', 'pdf-invoicing-for-woocommerce' );
		parent::__construct();
	}

	/**
	 * get_settings.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function get_settings() {

		$plugin_settings = array(
			array(
				'title'    => __( 'PDF Invoicing Options', 'pdf-invoicing-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_pdf_invoicing_plugin_options',
			),
			array(
				'title'    => __( 'PDF Invoicing', 'pdf-invoicing-for-woocommerce' ),
				'desc'     => '<strong>' . __( 'Enable plugin', 'pdf-invoicing-for-woocommerce' ) . '</strong>',
				'desc_tip' => __( 'Add PDF invoices to WooCommerce.', 'pdf-invoicing-for-woocommerce' ),
				'id'       => 'alg_wc_pdf_invoicing_plugin_enabled',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_pdf_invoicing_plugin_options',
			),
		);

		$general_settings = array(
			array(
				'title'    => __( 'General Options', 'pdf-invoicing-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_pdf_invoicing_general_options',
			),
			array(
				'title'    => __( 'Total documents', 'pdf-invoicing-for-woocommerce' ),
				'desc_tip' => __( 'Sets total number of documents you wish to add.', 'pdf-invoicing-for-woocommerce' ) . ' ' .
					__( 'After you save changes, new settings sections will be displayed.', 'pdf-invoicing-for-woocommerce' ),
				'desc'     => apply_filters( 'alg_wc_pdf_invoicing_settings',
					'You will need <a href="https://wpfactory.com/item/pdf-invoicing-for-woocommerce/" target="_blank">PDF Invoicing for WooCommerce Pro</a> to add more than one document type.',
					'button' ),
				'id'       => 'alg_wc_pdf_invoicing_total_docs',
				'default'  => 1,
				'type'     => 'number',
				'custom_attributes' => apply_filters( 'alg_wc_pdf_invoicing_settings', array( 'readonly' => 'readonly' ), 'array' ),
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_pdf_invoicing_general_options',
			),
		);

		return array_merge( $plugin_settings, $general_settings );
	}

}

endif;

return new Alg_WC_PDF_Invoicing_Settings_General();
