<?php
/**
 * PDF Invoicing for WooCommerce - Settings
 *
 * @version 1.0.0
 * @since   1.0.0
 * @author  Algoritmika Ltd
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_PDF_Invoicing_Settings' ) ) :

class Alg_WC_PDF_Invoicing_Settings extends WC_Settings_Page {

	/**
	 * Constructor.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function __construct() {
		$this->id    = 'alg_wc_pdf_invoicing';
		$this->label = __( 'PDF Invoicing', 'pdf-invoicing-for-woocommerce' );
		parent::__construct();
		add_filter( 'woocommerce_admin_settings_sanitize_option', array( $this, 'sanitize_as_textarea' ), PHP_INT_MAX, 3 );
		// Sections
		require_once( 'class-alg-wc-pdf-invoicing-settings-section.php' );
		require_once( 'class-alg-wc-pdf-invoicing-settings-doc.php' );
		$this->sections = array();
		$this->sections['general']  = require_once( 'class-alg-wc-pdf-invoicing-settings-general.php' );
		$this->sections['doc_0']    = new Alg_WC_PDF_Invoicing_Settings_Doc();
		do_action( 'alg_wc_pdf_invoicing_admin_doc_settings_loaded', $this );
		$this->sections['counters'] = require_once( 'class-alg-wc-pdf-invoicing-settings-counters.php' );
	}

	/**
	 * sanitize_as_textarea.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function sanitize_as_textarea( $value, $option, $raw_value ) {
		return ( ! empty( $option['sanitize_as_textarea'] ) ? wp_kses_post( trim( $raw_value ) ) : $value );
	}

	/**
	 * get_settings.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function get_settings() {
		global $current_section;
		return array_merge( apply_filters( 'woocommerce_get_settings_' . $this->id . '_' . $current_section, array() ), array(
			array(
				'title'     => __( 'Reset Settings', 'pdf-invoicing-for-woocommerce' ),
				'type'      => 'title',
				'id'        => $this->id . '_' . $current_section . '_reset_options',
			),
			array(
				'title'     => __( 'Reset section settings', 'pdf-invoicing-for-woocommerce' ),
				'desc'      => '<strong>' . __( 'Reset', 'pdf-invoicing-for-woocommerce' ) . '</strong>',
				'desc_tip'  => __( 'Check the box and save changes to reset.', 'pdf-invoicing-for-woocommerce' ),
				'id'        => $this->id . '_' . $current_section . '_reset',
				'default'   => 'no',
				'type'      => 'checkbox',
			),
			array(
				'type'      => 'sectionend',
				'id'        => $this->id . '_' . $current_section . '_reset_options',
			),
		) );
	}

	/**
	 * maybe_reset_settings.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function maybe_reset_settings() {
		global $current_section;
		if ( 'yes' === get_option( $this->id . '_' . $current_section . '_reset', 'no' ) ) {
			foreach ( $this->get_settings() as $value ) {
				if ( isset( $value['id'] ) ) {
					$id = explode( '[', $value['id'] );
					delete_option( $id[0] );
				}
			}
			add_action( 'admin_notices', array( $this, 'admin_notices_settings_reset_success' ), PHP_INT_MAX );
		}
	}

	/**
	 * admin_notices_settings_reset_success.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function admin_notices_settings_reset_success() {
		echo '<div class="notice notice-success is-dismissible"><p><strong>' .
			__( 'Your settings have been reset.', 'pdf-invoicing-for-woocommerce' ) . '</strong></p></div>';
	}

	/**
	 * save.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @todo    [dev] fix notices (not showing now because of redirect)
	 */
	function save() {
		parent::save();
		$this->maybe_reset_settings();
		wp_safe_redirect( add_query_arg( array() ) );
		exit;
	}

}

endif;

return new Alg_WC_PDF_Invoicing_Settings();
