<?php
/*
Plugin Name: PDF Invoicing for WooCommerce
Plugin URI: https://wpfactory.com/item/pdf-invoicing-for-woocommerce/
Description: Add PDF invoices to WooCommerce.
Version: 1.1.1
Author: Algoritmika Ltd
Author URI: https://algoritmika.com
Text Domain: pdf-invoicing-for-woocommerce
Domain Path: /langs
Copyright:  2020 Algoritmika Ltd
WC tested up to: 3.9
License: GNU General Public License v3.0
License URI: http://www.gnu.org/licenses/gpl-3.0.html
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_PDF_Invoicing' ) ) :

/**
 * Main Alg_WC_PDF_Invoicing Class
 *
 * @class   Alg_WC_PDF_Invoicing
 * @version 1.0.0
 * @since   1.0.0
 */
final class Alg_WC_PDF_Invoicing {

	/**
	 * Plugin version.
	 *
	 * @var   string
	 * @since 1.0.0
	 */
	public $version = '1.1.1';

	/**
	 * @var   Alg_WC_PDF_Invoicing The single instance of the class
	 * @since 1.0.0
	 */
	protected static $_instance = null;

	/**
	 * Main Alg_WC_PDF_Invoicing Instance
	 *
	 * Ensures only one instance of Alg_WC_PDF_Invoicing is loaded or can be loaded.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @static
	 * @return  Alg_WC_PDF_Invoicing - Main instance
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Alg_WC_PDF_Invoicing Constructor.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @access  public
	 */
	function __construct() {

		// Check for active plugins
		if (
			! $this->is_plugin_active( 'woocommerce/woocommerce.php' ) ||
			( 'pdf-invoicing-for-woocommerce.php' === basename( __FILE__ ) && $this->is_plugin_active( 'pdf-invoicing-for-woocommerce-pro/pdf-invoicing-for-woocommerce-pro.php' ) )
		) {
			return;
		}

		// Set up localisation
		load_plugin_textdomain( 'pdf-invoicing-for-woocommerce', false, dirname( plugin_basename( __FILE__ ) ) . '/langs/' );

		// Pro
		if ( 'pdf-invoicing-for-woocommerce-pro.php' === basename( __FILE__ ) ) {
			require_once( 'includes/pro/class-alg-wc-pdf-invoicing-pro.php' );
		}

		// Core
		$this->core = require_once( 'includes/class-alg-wc-pdf-invoicing-core.php' );

		// Admin
		if ( is_admin() ) {
			require_once( 'includes/class-alg-wc-pdf-invoicing-admin.php' );
		}

	}

	/**
	 * is_plugin_active.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function is_plugin_active( $plugin ) {
		return ( function_exists( 'is_plugin_active' ) ? is_plugin_active( $plugin ) :
			(
				in_array( $plugin, apply_filters( 'active_plugins', ( array ) get_option( 'active_plugins', array() ) ) ) ||
				( is_multisite() && array_key_exists( $plugin, ( array ) get_site_option( 'active_sitewide_plugins', array() ) ) )
			)
		);
	}

	/**
	 * plugin_url.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @return  string
	 */
	function plugin_url() {
		return untrailingslashit( plugin_dir_url( __FILE__ ) );
	}

	/**
	 * plugin_path.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @return  string
	 */
	function plugin_path() {
		return untrailingslashit( plugin_dir_path( __FILE__ ) );
	}

	/**
	 * plugin_file.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function plugin_file() {
		return __FILE__;
	}

}

endif;

if ( ! function_exists( 'alg_wc_pdf_invoicing' ) ) {
	/**
	 * Returns the main instance of Alg_WC_PDF_Invoicing to prevent the need to use globals.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @return  Alg_WC_PDF_Invoicing
	 */
	function alg_wc_pdf_invoicing() {
		return Alg_WC_PDF_Invoicing::instance();
	}
}

add_action( 'plugins_loaded', 'alg_wc_pdf_invoicing' );
